@@ -8,7 +8,7 @@ if [ "$1" = "--noconfigure" ]; then
     exit 0;
 fi
 
-if [ -z "$@" ]; then
+if [ X"$@" = X  -a "X`uname -s`" = "XLinux" ]; then
     ./configure --prefix=/usr
 else
     ./configure "$@"
