@@ -33,6 +33,8 @@ int build(char *arg, int buildAmount, char *passPhrase,
     char buf[BUFSIZ];
     Spec spec = NULL;
 
+    rpmSetTables(RPM_MACHTABLE_BUILDARCH, RPM_MACHTABLE_BUILDOS);
+
     if (fromTarball) {
 	specDir = rpmGetVar(RPMVAR_SPECDIR);
 	tmpSpecFile = alloca(BUFSIZ);
@@ -118,7 +120,7 @@ int build(char *arg, int buildAmount, char *passPhrase,
 	return 1;
     }
     
-    if (!(fd = open(specfile, O_RDONLY))) {
+    if ((fd = open(specfile, O_RDONLY)) < 0) {
 	fprintf(stderr, _("Unable to open spec file: %s\n"), specfile);
 	return 1;
     }
@@ -134,9 +136,13 @@ int build(char *arg, int buildAmount, char *passPhrase,
 	s++;
     }
 
-    if (parseSpec(&spec, specfile, buildRoot, 0, passPhrase, cookie)) {
-	return 1;
+#define	_anyarch(_f)	\
+(((_f)&(RPMBUILD_PACKAGESOURCE|RPMBUILD_PACKAGEBINARY)) == RPMBUILD_PACKAGESOURCE)
+    if (parseSpec(&spec, specfile, buildRoot, 0, passPhrase, cookie,
+	_anyarch(buildAmount))) {
+	    return 1;
     }
+#undef	_anyarch
 
     if (buildSpec(spec, buildAmount, test)) {
 	freeSpec(spec);
