@@ -9,6 +9,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
+#include "intl.h"
 #include "falloc.h"
 
 #define FA_MAGIC      0x02050920
@@ -133,8 +134,8 @@ unsigned int faAlloc(faFile fa, unsigned int size) { /* returns 0 on failure */
 	if (read(fa->fd, &header, sizeof(header)) != sizeof(header)) return 0;
 
 	if (!header.isFree) {
-	    fprintf(stderr, "free list corrupt (%d)- contact "
-			"support@redhat.com\n", nextFreeBlock);
+	    fprintf(stderr, _("free list corrupt (%d)- contact "
+			"support@redhat.com\n"), nextFreeBlock);
 	    exit(1);
 	}
 
