@@ -60,13 +60,13 @@ static int readPackageHeaders(int fd, struct rpmlead * leadPtr,
     }
 
     if (lead->major == 1) {
-	rpmMessage(RPMMESS_DEBUG, "package is a version one package!\n");
+	rpmMessage(RPMMESS_DEBUG, _("package is a version one package!\n"));
 
 	if (lead->type == RPMLEAD_SOURCE) {
-	    rpmMessage(RPMMESS_DEBUG, "old style source package -- "
-			"I'll do my best\n");
+	    rpmMessage(RPMMESS_DEBUG, _("old style source package -- "
+			"I'll do my best\n"));
 	    oldLead->archiveOffset = ntohl(oldLead->archiveOffset);
-	    rpmMessage(RPMMESS_DEBUG, "archive offset is %d\n", 
+	    rpmMessage(RPMMESS_DEBUG, _("archive offset is %d\n"), 
 			oldLead->archiveOffset);
 	    lseek(fd, oldLead->archiveOffset, SEEK_SET);
 	    
@@ -76,7 +76,7 @@ static int readPackageHeaders(int fd, struct rpmlead * leadPtr,
 
 	    *hdr = NULL;
 	} else {
-	    rpmMessage(RPMMESS_DEBUG, "old style binary package\n");
+	    rpmMessage(RPMMESS_DEBUG, _("old style binary package\n"));
 	    readOldHeader(fd, hdr, &isSource);
 	    arch = lead->archnum;
 	    headerAddEntry(*hdr, RPMTAG_ARCH, RPM_INT8_TYPE, &arch, 1);
@@ -183,7 +183,7 @@ static int readOldHeader(int fd, Header * hdr, int * isSource) {
 	     spec.distribution, 1);
     headerAddEntry(dbentry, RPMTAG_VENDOR, RPM_STRING_TYPE, spec.vendor, 1);
     headerAddEntry(dbentry, RPMTAG_SIZE, RPM_INT32_TYPE, &oldheader.size, 1);
-    headerAddEntry(dbentry, RPMTAG_COPYRIGHT, RPM_STRING_TYPE, spec.copyright, 1); 
+    headerAddEntry(dbentry, RPMTAG_LICENSE, RPM_STRING_TYPE, spec.copyright, 1); 
 
     if (oldheader.group)
 	headerAddEntry(dbentry, RPMTAG_GROUP, RPM_STRING_TYPE, oldheader.group, 1);
